<?php 
return [
  'menu' => [
    'qrcode' => 'QR Code',
  ],
  'type' => [
    'text' => 'Text',
    'email' => 'Email',
    'url' => 'URL',
    'tel' => 'Phone',
    'sms' => 'SMS',
    'whatsapp' => 'WhatsApp',
    'skype' => 'Skype',
    'zoom' => 'Zoom',
    'wifi' => 'WiFi',
    'geo' => 'Location',
    'paypal' => 'PayPal',
    'event' => 'Event',
    'upi' => 'UPI',
  ],
  'fields' => [
    'message' => 'Message',
    'qrTitle' => 'QR Title',
    'logo' => 'Logo',
    'design' => 'Design',
    'type' => 'Type',
    'size' => 'Size',
    'margin' => 'Margin',
    'logo_size' => 'Logo Size',
    'background_color' => 'Background Color',
    'foreground_color' => 'Foreground Color',
    'url' => 'URL',
    'subject' => 'Subject',
    'username' => 'Username',
    'chat' => 'Chat',
    'call' => 'Call',
    'skypeContactType' => 'Skype Contact Type',
    'meetingUrl' => 'Meeting URL',
    'networkType' => 'Network Type',
    'networkName' => 'Network Name',
    'hidden' => 'Hidden',
    'noEncryption' => 'No Encryption',
    'wep' => 'WEP',
    'wpa' => 'WPA/WPA2/WPA3',
    'upiId' => 'UPI ID',
    'amount' => 'Amount',
    'currency' => 'Currency',
    'itemName' => 'Item Name',
    'itemId' => 'Item ID',
    'paypalEmailHelp' => 'Email address to receive payments',
    'paypalPaymentType' => 'Payment Type',
    'buyNow' => 'Buy Now',
    'donate' => 'Donate',
    'addCart' => 'Add to Cart',
    'shipping' => 'Shipping',
    'link' => 'Link',
    'reminder' => 'Reminder before event',
    'eventTitle' => 'Event Title',
    'location' => 'Location',
    'upiAmountHelp' => 'If amount is entered payee will not be able to change the amount',
  ],
  'format' => [
    'svg' => 'SVG',
    'png' => 'PNG',
    'gif' => 'GIF',
    'webp' => 'WEBP',
    'pdf' => 'PDF',
    'eps' => 'EPS',
  ],
  'createQrCode' => 'Create QR Code',
  'editQrCode' => 'Edit QR Code',
  'invalidType' => 'Selected type is not available. Please select another type.',
  'event' => [
    'reminder' => [
      'start' => 'When the event starts',
      '5m' => '5 minutes',
      '10m' => '10 minutes',
      '15m' => '15 minutes',
      '30m' => '30 minutes',
      '1h' => '1 hour',
      '2h' => '2 hours',
      '3h' => '3 hours',
      '4h' => '4 hours',
      '5h' => '5 hours',
      '6h' => '6 hours',
      '12h' => '12 hours',
      '24h' => '24 hours',
      '48h' => '48 hours',
      '1w' => '1 week',
    ],
  ],
  'generateQrPreview' => 'Generate QR Preview',
  'qrGenerateWarning' => 'Make sure Background and foreground colors have a sufficient contrast ratio.',
];